\name{adaboost}
\alias{adaboost}
\title{adaboost}
\description{An implementation of the AdaBoost algorithm for binary
  classification}
\usage{adaboost(xlearn, ylearn, xtest, presel = 200, mfinal = 100)}
\arguments{
  \item{xlearn}{A (n x p)-matrix, where rows correspond to training
    instances and columns contain the predictor variables.}
  \item{ylearn}{A vector of length n containing the class labels, which
    need to be coded by 0 and 1.}
  \item{xtest}{A (m x p)-matrix, where rows correspond to test
      instances and columns contain the predictor variables.}
  \item{presel}{An integer, giving the number of features to be
    pre-selected according to the Wilcoxon test statistic. Default is
    presel=200 features. If presel=0, no feature preselection is carried
    out.}
  \item{mfinal}{An integer, the number of iterations for which boosting
    is run. Defaults to mfinal=100 iterations.}}
\value{The function outputs an array, whose rows contain out-of-sample
  probabilities that the class labels are predicted as being of class 1,
  for every boosting iteration.}
\references{
  \item{o}{"Boosting for Tumor Classification with Gene Expression
    Data", Marcel Dettling and Peter B\"uhlmann. Bioinformatics (2003),
    Vol. 19, p. 1061--1069.}
  \item{o}{"BagBoosting for Tumor Classification with Gene Expression
    Data", Marcel Dettling. To appear in Bioinformatics (2005).}
  \item{o}{Further information is available from the webpage
    \url{http://stat.ethz.ch/~dettling}}
  }
\author{Marcel Dettling}
\examples{
data(leukemia, package = "boost")

## Dividing the leukemia dataset into training and test data
xlearn <- leukemia.x[c(1:20, 34:38),]
ylearn <- leukemia.y[c(1:20, 34:38)]
xtest  <- leukemia.x[21:33,]
ytest  <- leukemia.y[21:33]

## Classification with adaboost
fit <- adaboost(xlearn, ylearn, xtest, presel=50, mfinal=20)
summarize(fit, ytest)
}
\keyword{classif}

\eof
\name{bagboost}
\alias{bagboost}
\title{bagboost}
\description{{An implementation of the BagBoost algorithm for binary
  classification}
}
\usage{bagboost(xlearn, ylearn, xtest, presel = 200, mfinal = 100, bag = 50)}
\arguments{
  \item{xlearn}{A (n x p)-matrix, where rows correspond to training
    instances and columns contain the predictor variables.}
  \item{ylearn}{A vector of length n containing the class labels, which
    need to be coded by 0 and 1.}
  \item{xtest}{A (m x p)-matrix, where rows correspond to test
      instances and columns contain the predictor variables.}
  \item{presel}{An integer, giving the number of features to be
    pre-selected according to the Wilcoxon test statistic. Default is
    presel=200 features. If presel=0, no feature preselection is carried
    out.}
  \item{mfinal}{An integer, the number of iterations for which boosting
    is run. Defaults to mfinal=100 iterations}
  \item{bag}{An integer, the number of bagging steps that shall be done
    to obtain the weak learner. Defaults to bag=50 bagging iterations.}
}

\value{The function outputs an array, whose rows contain out-of-sample
  probabilities that the class labels are predicted as being of class 1,
  for every boosting iteration.}
\references{
  \item{o}{"Boosting for Tumor Classification with Gene Expression
    Data", Marcel Dettling and Peter B\"uhlmann. Bioinformatics (2003),
    Vol. 19, p. 1061--1069.}
  \item{o}{"BagBoosting for Tumor Classification with Gene Expression
    Data", Marcel Dettling. To appear in Bioinformatics (2005).}
  \item{o}{Further information is available from the webpage
    \url{http://stat.ethz.ch/~dettling}}
  }
\author{Marcel Dettling}
\examples{
data(leukemia, package = "boost")

## Dividing the leukemia dataset into training and test data
xlearn <- leukemia.x[c(1:20, 34:38),]
ylearn <- leukemia.y[c(1:20, 34:38)]
xtest  <- leukemia.x[21:33,]
ytest  <- leukemia.y[21:33]

## Classification with bagboost
fit <- bagboost(xlearn, ylearn, xtest, presel=50, mfinal=20, bag=5)
summarize(fit, ytest)
}
\keyword{classif}


\eof
\name{l2boost}
\alias{l2boost}
\title{l2boost}
\description{An implementation of the LogitBoost algorithm for binary
  classification}
\usage{l2boost(xlearn, ylearn, xtest, presel = 200, mfinal = 100)}
\arguments{
  \item{xlearn}{A (n x p)-matrix, where rows correspond to training
    instances and columns contain the predictor variables.}
  \item{ylearn}{A vector of length n containing the class labels, which
    need to be coded by 0 and 1.}
  \item{xtest}{A (m x p)-matrix, where rows correspond to test
      instances and columns contain the predictor variables.}
  \item{presel}{An integer, giving the number of features to be
    pre-selected according to the Wilcoxon test statistic. Default is
    presel=200 features. If presel=0, no feature preselection is carried
    out.}
  \item{mfinal}{An integer, the number of iterations for which boosting
    is run. Defaults to mfinal=100 iterations}
}
\value{The function outputs an array, whose rows contain out-of-sample
  probabilities that the class labels are predicted as being of class 1,
  for every boosting iteration.}
\references{
  \item{o}{"Boosting for Tumor Classification with Gene Expression
    Data", Marcel Dettling and Peter B\"uhlmann. Bioinformatics (2003),
    Vol. 19, p. 1061--1069.}
  \item{o}{"BagBoosting for Tumor Classification with Gene Expression
    Data", Marcel Dettling. To appear in Bioinformatics (2005).}
  \item{o}{Further information is available from the webpage
    \url{http://stat.ethz.ch/~dettling}}
  }
\author{Marcel Dettling}
\examples{
data(leukemia, package = "boost")

## Dividing the leukemia dataset into training and test data
xlearn <- leukemia.x[c(1:20, 34:38),]
ylearn <- leukemia.y[c(1:20, 34:38)]
xtest  <- leukemia.x[21:33,]
ytest  <- leukemia.y[21:33]

## Classification with l2boost
fit <- l2boost(xlearn, ylearn, xtest, presel=50, mfinal=20)
summarize(fit, ytest)
}
\keyword{classif}


\eof
\name{learner}
\alias{learner}
\alias{response1}
\alias{response2}
\alias{response3}
\alias{score}
\title{Internal functions for the boost package.}
\description{These are not to be called by the user.}
\seealso{simulator, logitboost, bagboost, adaboost, l2boost}
\keyword{classif}

\eof
\name{leukemia}
\alias{leukemia}
\alias{leukemia.x}
\alias{leukemia.y}
\alias{leukemia.z}
\non_function{}
\title{A part of the famous AML/ALL-leukemia dataset}
\description{This is the training set of the famous AML/ALL-leukemia
  dataset from the Whitehead Institute. It has been reduced to 250
  genes, about the half of which are very informative for
  classification, whereas the other half was chosen randomly.}
\usage{data(leukemia)}
\format{Contains three R-objects: The expression matrix leukemia.x, the
  associated binary response variable leukemia.y, and the associated
  3-class response variable leukemia.z}
\source{http://www.genome.wi.mit.edu/MPR}
\references{First published in Golub et al: Molecular Classification of
  Cancer: Class Discovery and Class Prediction by Gene Expression
  Monitoring. Science 1999, 286: 531-538.}
\examples{
data(leukemia)
str(leukemia.x)
str(leukemia.y)
str(leukemia.z)
par(mfrow=c(1,2))
plot(leukemia.x[,56], leukemia.y)
plot(leukemia.x[,174],leukemia.z)}
\keyword{datasets}




\eof
\name{logitboost}
\alias{logitboost}
\title{logitboost}
\description{An implementation of the LogitBoost algorithm for binary
  classification} 
\usage{logitboost(xlearn, ylearn, xtest, presel = 200, mfinal = 100)}
\arguments{
  \item{xlearn}{A (n x p)-matrix, where rows correspond to training
    instances and columns contain the predictor variables.}
  \item{ylearn}{A vector of length n containing the class labels, which
    need to be coded by 0 and 1.}
  \item{xtest}{A (m x p)-matrix, where rows correspond to test
      instances and columns contain the predictor variables.}
  \item{presel}{An integer, giving the number of features to be
    pre-selected according to the Wilcoxon test statistic. Default is
    presel=200 features. If presel=0, no feature preselection is carried
    out.}
  \item{mfinal}{An integer, the number of iterations for which boosting
    is run. Defaults to mfinal=100 iterations}
}
\value{The function outputs an array, whose rows contain out-of-sample
  probabilities that the class labels are predicted as being of class 1,
  for every boosting iteration.}
\references{
  \item{o}{"Boosting for Tumor Classification with Gene Expression
    Data", Marcel Dettling and Peter B\"uhlmann. Bioinformatics (2003),
    Vol. 19, p. 1061--1069.}
  \item{o}{"BagBoosting for Tumor Classification with Gene Expression
    Data", Marcel Dettling. To appear in Bioinformatics (2005).}
  \item{o}{Further information is available from the webpage
    \url{http://stat.ethz.ch/~dettling}}
  }
\author{Marcel Dettling}
\examples{
data(leukemia, package = "boost")

## Dividing the leukemia dataset into training and test data
xlearn <- leukemia.x[c(1:20, 34:38),]
ylearn <- leukemia.y[c(1:20, 34:38)]
xtest  <- leukemia.x[21:33,]
ytest  <- leukemia.y[21:33]

## Classification with logitboost
fit <- logitboost(xlearn, ylearn, xtest, presel=50, mfinal=20)
summarize(fit, ytest)
}
\keyword{classif}


\eof
\name{simulator}
\alias{simulator}
\title{simulator}
\description{Simulation of (microarray) data according to correlation
  and mean structures from real datasets.}
\usage{simulator(x, y, respmod = c("none", "resp1", "resp2", "resp3"),
nos = 1200, gene = NULL, signs = NULL)}
\arguments{
  \item{x}{A (n x p)-matrix, whose correlation and mean structure is to
    be used for simulating data. Its rows correspond to training
    instances and columns contain the predictor variables.}
  \item{y}{A vector of length n containing the class labels, which
    need to be coded by 0 and 1.}
  \item{respmod}{A character string. Either "none" where the simulated
    gene expression labels are determined model-free depending which
    class mean and correlation structure had been used for their
    determination. The choice of "resp1", "resp2" and "resp3"
    means that a response model is applied. For "resp1", 10 genes are
    selected and determine conditional proabilities via a logistic model
    with equal weights. The class labels are then regarded as having a
    Bernoulli distribution with probability p. For "resp2", 25 genes
    are plugged into the logistic model with non-equal weights. With
    "resp3", 25 genes are chosen for a logistic model with second
    and third order interactions.}
  \item{nos}{An integer, giving the number of instances which are
    simulated.}
  \item{gene}{A vector giving the index of the genes which shall be used
    for model based class label simulation. Defaults to NULL. This
    argument should only be used for specially designed simulation
    studies, where it is important that the same predictor variables are
    repeatedly used for simulating class label.}
  \item{signs}{A vector containing entries of +1 and -1. Defaults to
    NULL and is only of importance in specially designed simulation
    studies, where it is important that the same predictor variables are
    repeatedly used for simulating class label. }
}
\details{The new instances are simulated according to a multivariate
  normal distribution with means and correlation structure taken from a
  real (gene expression) dataset. This structure is obtained by
  transforming a standard multivariate normal distribution, which
  requires a eigenvalue decomposition of the provided real dataset. For
  datasets with many predictors (>500), this can be fairly time
  consuming. Simulating data without applying a response model is fine
  for most purposes, only special analysis tasks usually require it.}
\value{Returns a list containing
  \item{x}{An (nos x p)-matrix, containing the simulated data}
  \item{y}{A vector of length nos, containing the class labels of the
    simulated data.}
  \item{probab}{A vector of length nos, containing the conditional
    probabilities of the simulated data. Is empty if respmod="none".}
  \item{bayes}{An integer, giving the Bayes error (theoretically minimal
    misclassification risk) for the simulated data. Is empty if 
    respmod="none".}
  \item{gene}{A vector, containing the indices of the variables which
    had been used in the logistic model for either "resp1", "resp2" or
    "resp3". Is empty if respmod="none".}
  \item{signs}{A vector, containing -1 and +1. Indicates with what
    polarization a predictor variable had been used in the logistic
    model. Is empty if respmod="none".}b
}
\references{
  \item{o}{"BagBoosting for Tumor Classification with Gene Expression
    Data", Marcel Dettling. To appear in Bioinformatics (2005).}
  \item{o}{Further information is available from the webpage
    \url{http://stat.ethz.ch/~dettling}}
}
\examples{
set.seed(21)
data(leukemia)

## Simulation of gene expression data
simu <- simulator(leukemia.x, leukemia.y, nos=200)

## Defining training and test data
xlearn <- simu$x[1:150,]
ylearn <- simu$y[1:150]
xtest  <- simu$x[151:200,]
ytest  <- simu$y[151:200]

## Classification with logitboost
fit <- logitboost(xlearn, ylearn, xtest, mfinal=20, presel=50)
summarize(fit, ytest)
}
\keyword{classif}

\eof
\name{summarize}
\alias{summarize}
\title{Summarize the output of classification with boosting functions}
\description{Yields text and graphical output that summarizes the
  misclassifcation error rates that have been achieved with boosting methods}
\usage{summarize(boost.out, resp, mout = ncol(boost.out), grafik = TRUE)}
\arguments{
  \item{boost.out}{An R-object, as obtained from one of the functions
    'bagboost', 'logitboost', 'adaboost' or 'l2boost'.}
  \item{resp}{A vector containing the class labels of the test
    instances. Needs to be coded by 0 and 1.}
  \item{mout}{The number of boosting iterations for which the error rate
  shall be printed. Defaults to the number of iterations boosting has
  been run for.}
  \item{grafik}{Logical, indicating whether a plot of the error rates is
  desired or not.}
}
\value{Just verbatim and graphical output.}
\references{
  \item{o}{"Boosting for Tumor Classification with Gene Expression
    Data", Marcel Dettling and Peter B\"uhlmann. Bioinformatics (2003),
    Vol. 19, p. 1061--1069.}
  \item{o}{"BagBoosting for Tumor Classification with Gene Expression
    Data", Marcel Dettling. To appear in Bioinformatics (2005).}
  \item{o}{Further information is available from the webpage
    \url{http://stat.ethz.ch/~dettling}}
  }
\author{Marcel Dettling}
\seealso{bagboost, logitboost, adaboost, l2boost}
\examples{
data(leukemia, package = "boost")

## Dividing the leukemia dataset into training and test data
xlearn <- leukemia.x[c(1:20, 34:38),]
ylearn <- leukemia.y[c(1:20, 34:38)]
xtest  <- leukemia.x[21:33,]
ytest  <- leukemia.y[21:33]

## Classification with logitboost
fit <- logitboost(xlearn, ylearn, xtest, presel=50, mfinal=20)
summarize(fit, ytest)
}
\keyword{classif}

\eof
